@@ -25,22 +25,14 @@
 #include "magnifier-private.h"
 #include "zoom-region.h"
 #include "zoom-region-private.h"
-#include "gmag-events.h"
+#include "gmag-cursor.h"
+#include "gmag-graphical-server.h"
 #include "GNOME_Magnifier.h"
 
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h>
 
-#include <X11/Xatom.h>
-#ifdef HAVE_XFIXES
-#include <X11/extensions/Xfixes.h>
-#ifdef HAVE_COMPOSITE
-#include <X11/extensions/shape.h>
-#include <X11/extensions/Xcomposite.h>
-#endif /* HAVE_COMPOSITE */
-#endif /* HAVE_XFIXES */
-
 #include <libbonobo.h>
 #include <login-helper/login-helper.h>
 
@@ -72,21 +64,6 @@ typedef struct
 
 static GObjectClass *parent_class = NULL;
 
-enum {
-	STRUT_LEFT = 0,
-	STRUT_RIGHT = 1,
-	STRUT_TOP = 2,
-	STRUT_BOTTOM = 3,
-	STRUT_LEFT_START = 4,
-	STRUT_LEFT_END = 5,
-	STRUT_RIGHT_START = 6,
-	STRUT_RIGHT_END = 7,
-	STRUT_TOP_START = 8,
-	STRUT_TOP_END = 9,
-	STRUT_BOTTOM_START = 10,
-	STRUT_BOTTOM_END = 11
-};
-
 enum {
 	MAGNIFIER_SOURCE_DISPLAY_PROP,
 	MAGNIFIER_TARGET_DISPLAY_PROP,
@@ -139,13 +116,11 @@ gchar* mag_prop_names[MAGNIFIER_CROSSWIRE_COLOR_PROP + 1] = {
 };
 #endif
 
-static int _x_error = 0;
 static Magnifier *_this_magnifier = NULL;
 extern gint       fixes_event_base;
 
 static void magnifier_init_cursor_set (Magnifier *magnifier, gchar *cursor_set);
 static void magnifier_init_window (Magnifier *magnifier, GdkScreen *screen);
-static gboolean magnifier_check_set_struts (Magnifier *magnifier);
 static gboolean magnifier_reset_struts_at_idle (gpointer data);
 static void magnifier_init_window (Magnifier *magnifier, GdkScreen *screen);
 static void magnifier_adjust_source_size (Magnifier *magnifier);
@@ -210,29 +185,6 @@ BONOBO_TYPE_FUNC (MagLoginHelper,
 		  LOGIN_HELPER_TYPE,
 		  mag_login_helper)
 
-gboolean
-magnifier_error_check (void)
-{
-	if (_x_error) {
-		_x_error = 0;
-		return TRUE;
-	}
-	return FALSE;
-}
-
-static int
-magnifier_x_error_handler (Display	 *display,
-			   XErrorEvent *error)
-{
-	if (error->error_code == BadAlloc) {
-		_x_error = error->error_code;
-	}
-	else {
-		return -1;
-	}
-	return 0;
-}
-
 static gboolean
 can_open_display (gchar *display_name)
 {
@@ -296,7 +248,8 @@ magnifier_zoom_regions_mark_dirty (Magnifier *magnifier, GNOME_Magnifier_RectBou
 }
 
 void
-magnifier_set_cursor_from_pixbuf (Magnifier *magnifier, GdkPixbuf *cursor_pixbuf)
+magnifier_set_cursor_from_pixbuf (Magnifier *magnifier,
+				  GdkPixbuf *cursor_pixbuf)
 {
 	GdkPixmap *pixmap, *mask;
 	gint width, height;
@@ -307,21 +260,21 @@ magnifier_set_cursor_from_pixbuf (Magnifier *magnifier, GdkPixbuf *cursor_pixbuf
 		g_object_unref (magnifier->priv->cursor);
 		magnifier->priv->cursor = NULL;
 	}
-	if (drawable && cursor_pixbuf)
-	{
+	if (drawable && cursor_pixbuf) {
 		const gchar *xhot_string = NULL, *yhot_string = NULL;
 		width = gdk_pixbuf_get_width (cursor_pixbuf);
 		height = gdk_pixbuf_get_height (cursor_pixbuf);
 		pixmap = gdk_pixmap_new (drawable, width, height, -1);
 		gc = gdk_gc_new (pixmap);
 		if (GDK_IS_DRAWABLE (pixmap))
-		    gdk_draw_pixbuf (pixmap, gc, cursor_pixbuf, 0, 0, 0, 0, 
-				     width, height,
-				     GDK_RGB_DITHER_NONE, 0, 0);
+			gdk_draw_pixbuf (pixmap, gc, cursor_pixbuf, 0, 0, 0, 0,
+					 width, height, GDK_RGB_DITHER_NONE,
+					 0, 0);
 		else
-		    DBG (g_warning ("empty cursor pixmap created."));
+			DBG (g_warning ("empty cursor pixmap created."));
 		mask = gdk_pixmap_new (drawable, width, height, 1);
-		gdk_pixbuf_render_threshold_alpha (cursor_pixbuf, mask, 0, 0, 0, 0, 
+		gdk_pixbuf_render_threshold_alpha (cursor_pixbuf, mask,
+						   0, 0, 0, 0, 
 						   width, height,
 						   200);
 		g_object_unref (gc);
@@ -329,15 +282,19 @@ magnifier_set_cursor_from_pixbuf (Magnifier *magnifier, GdkPixbuf *cursor_pixbuf
 		magnifier->priv->cursor_mask = mask;
 		xhot_string = gdk_pixbuf_get_option (cursor_pixbuf,"x_hot");
 		yhot_string = gdk_pixbuf_get_option (cursor_pixbuf,"y_hot");
-		if (xhot_string) magnifier->cursor_hotspot.x = atoi (xhot_string);
-		if (yhot_string) magnifier->cursor_hotspot.y = atoi (yhot_string);
-
+		if (xhot_string)
+			magnifier->cursor_hotspot.x = atoi (xhot_string);
+		if (yhot_string)
+			magnifier->cursor_hotspot.y = atoi (yhot_string);
 		if (pixmap) {
-			gdk_drawable_get_size (pixmap,
-					       &magnifier->priv->cursor_default_size_x,
-					       &magnifier->priv->cursor_default_size_y);
-			magnifier->priv->cursor_hotspot_x = magnifier->cursor_hotspot.x;
-			magnifier->priv->cursor_hotspot_y = magnifier->cursor_hotspot.y;
+			gdk_drawable_get_size (
+				pixmap,
+				&magnifier->priv->cursor_default_size_x,
+				&magnifier->priv->cursor_default_size_y);
+			magnifier->priv->cursor_hotspot_x =
+				magnifier->cursor_hotspot.x;
+			magnifier->priv->cursor_hotspot_y =
+				magnifier->cursor_hotspot.y;
 		}
 	}
 }
@@ -362,12 +319,9 @@ magnifier_set_cursor_pixmap_by_name (Magnifier *magnifier,
 	GdkPixbuf *pixbuf;
 	/* search local table; if not found, use source screen's cursor if source_fallback is TRUE */
 	if ((pixbuf = magnifier_get_pixbuf_for_name (magnifier, cursor_name)) == NULL) {
-#ifndef HAVE_XFIXES
-		source_fallback = FALSE;
-#endif
 		if (source_fallback == TRUE)
 		{
-			pixbuf = gmag_events_get_source_pixbuf (magnifier);
+			pixbuf = gmag_cursor_get_source_pixbuf (magnifier);
 		}
 		else
 		{
@@ -379,7 +333,7 @@ magnifier_set_cursor_pixmap_by_name (Magnifier *magnifier,
 }
 
 void
-magnifier_notify_damage (Magnifier *magnifier, XRectangle *rect)
+magnifier_notify_damage (Magnifier *magnifier, GdkRectangle *rect)
 {
 	GNOME_Magnifier_RectBounds rect_bounds;
 	rect_bounds.x1 = rect->x;
@@ -389,7 +343,8 @@ magnifier_notify_damage (Magnifier *magnifier, XRectangle *rect)
 #undef DEBUG_DAMAGE
 #ifdef DEBUG_DAMAGE
 	g_message ("damage");
-	g_message ("dirty %d, %d to %d, %d", rect_bounds.x1, rect_bounds.y1, rect_bounds.x2, rect_bounds.y2);
+	g_message ("dirty %d, %d to %d, %d", rect_bounds.x1, rect_bounds.y1,
+		   rect_bounds.x2, rect_bounds.y2);
 #endif
 	magnifier_zoom_regions_mark_dirty (magnifier, rect_bounds);
 }
@@ -397,64 +352,20 @@ magnifier_notify_damage (Magnifier *magnifier, XRectangle *rect)
 static void
 magnifier_set_extension_listeners (Magnifier *magnifier, GdkWindow *root)
 {
-	gmag_events_client_init (magnifier);
+	gmag_gs_client_init (magnifier);
 	magnifier->source_initialized = TRUE;
 }
 
 static void
 magnifier_size_allocate (GtkWidget *widget)
 {
-	magnifier_check_set_struts (_this_magnifier);
+	gmag_gs_check_set_struts (_this_magnifier);
 }
 
 static void
 magnifier_realize (GtkWidget *widget)
 {
-	XWMHints wm_hints;
-	Atom wm_window_protocols[2];
-	Atom wm_type_atoms[1];
-	Atom net_wm_window_type;
-	GdkDisplay *target_display = gdk_drawable_get_display (widget->window);
-	
-	static gboolean initialized = FALSE;
-
-#ifndef MAG_WINDOW_OVERRIDE_REDIRECT	
-	if (!initialized) {
-		wm_window_protocols[0] = gdk_x11_get_xatom_by_name_for_display (target_display,
-										"WM_DELETE_WINDOW");
-		wm_window_protocols[1] = gdk_x11_get_xatom_by_name_for_display (target_display,
-										"_NET_WM_PING");
-		/* use DOCK until Metacity RFE for new window type goes in */
-                wm_type_atoms[0] = gdk_x11_get_xatom_by_name_for_display (target_display,
-									  "_NET_WM_WINDOW_TYPE_DOCK");
-	}
-  
-	wm_hints.flags = InputHint;
-	wm_hints.input = False;
-	
-	XSetWMHints (GDK_WINDOW_XDISPLAY (widget->window),
-		     GDK_WINDOW_XWINDOW (widget->window), &wm_hints);
-	
-	XSetWMProtocols (GDK_WINDOW_XDISPLAY (widget->window),
-			 GDK_WINDOW_XWINDOW (widget->window), wm_window_protocols, 2);
-
-	net_wm_window_type = gdk_x11_get_xatom_by_name_for_display 
-		(target_display, "_NET_WM_WINDOW_TYPE");
-
-	if (net_wm_window_type && wm_type_atoms[0])
-		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window),
-				 GDK_WINDOW_XWINDOW (widget->window),
-				 net_wm_window_type,
-				 XA_ATOM, 32, PropModeReplace,
-				 (guchar *)wm_type_atoms,
-				 1);
-#else
-#endif
-	/* TODO: make sure this works/is reset if the DISPLAY 
-	 * (as well as the SCREEN) changes.
-	 */
-
-	XSetErrorHandler (magnifier_x_error_handler);
+	gmag_gs_magnifier_realize (widget);
 }
 
 GdkWindow*
@@ -863,13 +774,9 @@ magnifier_init_cursor_set (Magnifier *magnifier, gchar *cursor_set)
 	 * and create/apply the appropriate cursor settings
 	 */
 	magnifier->cursor_set = cursor_set;
-#ifdef HAVE_XFIXES	
 	magnifier->priv->use_source_cursor = 
 	    (!strcmp (cursor_set, "default") && 
 	     (fixes_event_base != 0));
-#else
-	magnifier->priv->use_source_cursor = FALSE;
-#endif
 	if (magnifier->priv->use_source_cursor) return;
 
 	if (!strcmp (magnifier->cursor_set, "none")) {
@@ -921,156 +828,21 @@ magnifier_init_cursor_set (Magnifier *magnifier, gchar *cursor_set)
 	magnifier_transform_cursor (magnifier);
 }
 
-static gboolean
-magnifier_reset_overlay_at_idle (gpointer data)
-{
-#ifdef HAVE_COMPOSITE
-	if (!g_getenv ("MAGNIFIER_IGNORE_COMPOSITE")) {
-		if (data) {
-			Magnifier *magnifier = MAGNIFIER (data);
-			if (magnifier->priv &&
-			    GTK_WIDGET_REALIZED (magnifier->priv->w)) 
-				if (magnifier->priv->w->window) {
-#ifdef HAVE_OVERLAY
-					gint      x, y, over_w, over_h;
-
-					magnifier->priv->overlay = gdk_window_foreign_new (XCompositeGetOverlayWindow (GDK_WINDOW_XDISPLAY (magnifier->priv->w->window), GDK_WINDOW_XID (magnifier->priv->root)));
-					gdk_window_get_position (
-						magnifier->priv->w->window,
-						&x, &y);
-					gdk_drawable_get_size (
-						magnifier->priv->w->window,
-						&over_w, &over_h);
-					gdk_window_move_resize (
-						magnifier->priv->overlay,
-						x, y, over_w, over_h);
-					gdk_window_reparent (
-						magnifier->priv->w->window,
-						magnifier->priv->overlay,
-						0, 0);
-#ifdef HAVE_SHAPEINPUT			
-					XShapeCombineRectangles (GDK_WINDOW_XDISPLAY (magnifier->priv->w->window), GDK_WINDOW_XID (magnifier->priv->overlay), ShapeInput, 0, 0, NULL, 0, ShapeSet, YXBanded);
-#endif /* HAVE_SHAPEINPUT */
-#else
-#ifdef HAVE_SHAPEINPUT
-					XShapeCombineRectangles (GDK_WINDOW_XDISPLAY (magnifier->priv->w->window), GDK_WINDOW_XID (magnifier->priv->w->window), ShapeInput, 0, 0, NULL, 0, ShapeSet, YXBanded);
-#endif /* HAVE_SHAPEINPUT */
-#endif /* HAVE_OVERLAY */
-					return FALSE;
-				}
-		}
-	} else
-		return FALSE;
-	return TRUE;
-#endif
-	return FALSE;
-}
-
 static gboolean 
 magnifier_reset_struts_at_idle (gpointer data)
 {
 	if (data)
 	{
 		Magnifier *magnifier = MAGNIFIER (data);
-		if (magnifier->priv && GTK_WIDGET_REALIZED (magnifier->priv->w) && 
-		    magnifier_check_set_struts (magnifier))
-		{
+		if (magnifier->priv &&
+		    GTK_WIDGET_REALIZED (magnifier->priv->w) && 
+		    gmag_gs_check_set_struts (magnifier)) {
 			return FALSE;
 		}
 	}
 	return TRUE;
 }
 
-static gboolean
-magnifier_check_set_struts (Magnifier *magnifier)
-{
-#ifdef HAVE_COMPOSITE
-	if (!g_getenv ("MAGNIFIER_IGNORE_COMPOSITE"))
-		return TRUE;
-#endif
-
-	if (magnifier &&
-	    magnifier->priv && magnifier->priv->w && GTK_WIDGET_REALIZED (magnifier->priv->w) &&
-	    magnifier->priv->w->window) 
-	{
-		Atom atom_strut = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT");
-		Atom atom_strut_partial = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT_PARTIAL");
-		guint32 struts[12] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
-		GtkWidget *widget = magnifier->priv->w;
-		gint width = gdk_screen_get_width (
-			gdk_display_get_screen (magnifier->target_display,
-						magnifier->target_screen_num));
-		gint height = gdk_screen_get_height (
-			gdk_display_get_screen (magnifier->target_display,
-						magnifier->target_screen_num));
-
-		gint right_margin, left_margin, top_margin, bottom_margin;
-		gint wx, wy, ww, wh;
-
-		gtk_window_get_position (GTK_WINDOW (magnifier->priv->w), &wx, &wy);
-		gtk_window_get_size (GTK_WINDOW (magnifier->priv->w), &ww, &wh);
-
-		left_margin = wx;
-		right_margin = (width - ww) - wx;
-		top_margin = wy;
-		bottom_margin = (height - wh) - wy;
-
-		/* set the WM_STRUT properties on the appropriate side */
-		if (bottom_margin > top_margin && 
-		    bottom_margin > left_margin &&
-		    bottom_margin > right_margin)
-		{
-			struts[STRUT_TOP] = wh + wy;
-			struts[STRUT_TOP_START] = wx;
-			struts[STRUT_TOP_END] = wx + ww;
-		} 
-		else if (top_margin > bottom_margin && 
-			 top_margin > left_margin &&
-			 top_margin > right_margin)
-		{
-			struts[STRUT_BOTTOM] = height - wy;
-			struts[STRUT_BOTTOM_START] = wx;
-			struts[STRUT_BOTTOM_END] = wx + ww;
-		}
-		else if (right_margin > left_margin &&
-			 right_margin > top_margin &&
-			 right_margin > bottom_margin)
-		{
-			struts[STRUT_LEFT] = wx;
-			struts[STRUT_LEFT_START] = wy;
-			struts[STRUT_LEFT_END] = wh + wy;
-		}
-		else 
-		{
-			struts[STRUT_RIGHT] = width - wx;
-			struts[STRUT_RIGHT_START] = wy;
-			struts[STRUT_RIGHT_END] = wy + wh;
-		}
-		
-		gdk_error_trap_push ();
-		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window), 
-				 GDK_WINDOW_XWINDOW (widget->window), 
-				 atom_strut,
-				 XA_CARDINAL, 32, PropModeReplace,
-				 (guchar *) &struts, 4);
-		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window), 
-				 GDK_WINDOW_XWINDOW (widget->window), 
-				 atom_strut_partial,
-				 XA_CARDINAL, 32, PropModeReplace,
-				 (guchar *) &struts, 12); 
-		gdk_error_trap_pop ();
-
-#ifdef DEBUG_STRUTS
-		g_message ("struts TOP %d (%d - %d)", struts[STRUT_TOP], struts[STRUT_TOP_START], struts[STRUT_TOP_END]);
-		g_message ("struts BOTTOM %d (%d - %d)", struts[STRUT_BOTTOM], struts[STRUT_BOTTOM_START], struts[STRUT_BOTTOM_END]);
-		g_message ("struts LEFT %d (%d - %d)", struts[STRUT_LEFT], struts[STRUT_LEFT_START], struts[STRUT_LEFT_END]);
-		g_message ("struts RIGHT %d (%d - %d)", struts[STRUT_RIGHT], struts[STRUT_RIGHT_START], struts[STRUT_RIGHT_END]);
-#endif
-		return TRUE;
-	}
-	return FALSE;
-}
-
 static void
 magnifier_get_property (BonoboPropertyBag *bag,
 			BonoboArg *arg,
@@ -1163,7 +935,7 @@ magnifier_set_property (BonoboPropertyBag *bag,
 						      full_display_string,
 						      NULL);
 		    magnifier->source_display =
-		    	gdk_display_open (full_display_string);
+			gdk_display_open (full_display_string);
 		    magnifier->source_display_name = g_strdup (full_display_string);
 		    zoom_region_params = magnifier_zoom_regions_save (magnifier);
 		    magnifier->priv->root =
@@ -1176,7 +948,7 @@ magnifier_set_property (BonoboPropertyBag *bag,
 		    magnifier_get_display_rect_bounds (magnifier, &magnifier->source_bounds, FALSE);
 		    magnifier_zoom_regions_restore (magnifier, zoom_region_params);
 		    magnifier_warp_cursor_to_screen (magnifier);
-		    magnifier_check_set_struts (magnifier);
+		    gmag_gs_check_set_struts (magnifier);
 		}
 		DBG(fprintf (stderr, "Set source display: \t%s\n", full_display_string));
 		break;
@@ -1248,7 +1020,7 @@ magnifier_set_property (BonoboPropertyBag *bag,
 		    /* N. B. we don't reset the target bounds to the limits of the new display, because */
 		    /* doing so would override the client-specified magnifier size */
 		    /* magnifier_get_display_rect_bounds (magnifier, &magnifier->target_bounds, TRUE); */
-		    magnifier_check_set_struts (magnifier);
+		    gmag_gs_check_set_struts (magnifier);
 		}
 		DBG(fprintf (stderr, "Set target display: \t%s (screen %d)\n", 
 			      full_display_string, magnifier->target_screen_num));
@@ -1283,7 +1055,7 @@ magnifier_set_property (BonoboPropertyBag *bag,
 		gtk_window_resize (GTK_WINDOW (magnifier->priv->w),
 				   magnifier->target_bounds.x2 - magnifier->target_bounds.x1,
 				   magnifier->target_bounds.y2 - magnifier->target_bounds.y1);
-		magnifier_check_set_struts (magnifier);
+		gmag_gs_check_set_struts (magnifier);
 		DBG(fprintf (stderr, "Set target size: \t%d,%d to %d,%d\n", 
 			      magnifier->target_bounds.x1, magnifier->target_bounds.y1, magnifier->target_bounds.x2, magnifier->target_bounds.y2));
 		if (!strcmp (magnifier->target_display_name, magnifier->source_display_name) && 
@@ -1378,9 +1150,9 @@ impl_magnifier_set_source_display (PortableServer_Servant servant,
 	full_display_string = g_strdup (display);
 	if (strcmp (full_display_string, "") == 0)
 		full_display_string = (gchar *) g_getenv ("DISPLAY");
-	
-	BONOBO_ARG_SET_STRING (arg, full_display_string);
 
+	BONOBO_ARG_SET_STRING (arg, full_display_string);
+	
 	DBG (fprintf (stderr, "Set source display: \t%s\n",
 		      full_display_string));
 
@@ -1411,7 +1183,7 @@ impl_magnifier_set_target_display (PortableServer_Servant servant,
 	full_display_string = g_strdup (display);
 	if (strcmp (full_display_string, "") == 0)
 		full_display_string = (gchar *) g_getenv ("DISPLAY");
-	
+
 	BONOBO_ARG_SET_STRING (arg, full_display_string);
 	
 	DBG (fprintf (stderr, "Set target display: \t%s\n",
@@ -1529,7 +1301,7 @@ impl_magnifier_add_zoom_region (PortableServer_Servant servant,
 
 	/* FIXME: this needs proper lifecycle management */
 	magnifier->zoom_regions = g_list_append (magnifier->zoom_regions, region);
-	magnifier_check_set_struts (magnifier);
+	gmag_gs_check_set_struts (magnifier);
 
 	return CORBA_TRUE;
 }
@@ -1815,6 +1587,10 @@ magnifier_init (Magnifier *magnifier)
 	magnifier->crosswire_clip = FALSE;
 	magnifier->cursor_hotspot.x = 0;
 	magnifier->cursor_hotspot.y = 0;
+	magnifier->target_bounds.x1 = 0;
+	magnifier->target_bounds.y1 = 0;
+	magnifier->target_bounds.x2 = 0;
+	magnifier->target_bounds.y2 = 0;
 	magnifier->priv->cursor = NULL;
 	magnifier->priv->w = NULL;
 	magnifier->priv->use_source_cursor = TRUE;
@@ -1853,16 +1629,13 @@ magnifier_get_cursor (Magnifier *magnifier)
 		    magnifier_transform_cursor (magnifier);
 		}
 		g_free (default_cursor_filename);
-	    }
-#ifdef HAVE_XFIXES
-	    else {
-		GdkPixbuf *cursor_pixbuf = gmag_events_get_source_pixbuf (
+	    } else {
+		GdkPixbuf *cursor_pixbuf = gmag_cursor_get_source_pixbuf (
 			magnifier);
 		magnifier_set_cursor_from_pixbuf (magnifier, cursor_pixbuf);
 		if (cursor_pixbuf) g_object_unref (cursor_pixbuf);
 		magnifier_transform_cursor (magnifier);
 	    }
-#endif
         }
 	return magnifier->priv->cursor;
 }
@@ -1888,17 +1661,17 @@ magnifier_new (gboolean override_redirect)
 	
 	ret = bonobo_activation_active_server_register (
 		MAGNIFIER_OAFIID, BONOBO_OBJREF (mag));
-	if (ret != Bonobo_ACTIVATION_REG_SUCCESS)
+	if (ret != Bonobo_ACTIVATION_REG_SUCCESS) {
 	    if ( ret == Bonobo_ACTIVATION_REG_ALREADY_ACTIVE)
 	    {
 		printf("An instance of magnifier is already active. Exiting Program.\n");
 		exit(0);
-	    }
-	    else
+	    } else
 		g_error ("Error registering magnifier server.\n");
+	}
 
 	g_idle_add (magnifier_reset_struts_at_idle, mag);
-	g_idle_add (magnifier_reset_overlay_at_idle, mag);
+	g_idle_add (gmag_gs_reset_overlay_at_idle, mag);
 
 	return mag;
 }
